EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NuGetPackages_PullCached',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Pulled_Indicator',
    /* Description_Text        */ 'Changes a cached package to a local package in a feed if it was found.'
GO

IF OBJECT_ID('[NuGetPackages_PullCached]') IS NOT NULL DROP PROCEDURE [NuGetPackages_PullCached]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO


CREATE PROCEDURE [NuGetPackages_PullCached]
(
	@Feed_Id INT,
	@Package_Id NVARCHAR(255),
	@Version_Text NVARCHAR(50),
	@Pulled_Indicator YNINDICATOR = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON

BEGIN TRY
	BEGIN TRANSACTION

	SET @Pulled_Indicator = 'N'

	SET @Version_Text = (SELECT CAST((CAST([Major] AS NVARCHAR(10))
	                         + (CASE WHEN [Minor] IS NOT NULL THEN '.' + CAST([Minor] AS NVARCHAR(10)) ELSE '' END)
						     + (CASE WHEN [Patch] IS NOT NULL THEN '.' + CAST([Patch] AS NVARCHAR(10)) ELSE '' END)
						     + (CASE WHEN [Build] IS NOT NULL THEN '.' + CAST([Build] AS NVARCHAR(10)) ELSE '' END)
						     + (CASE WHEN [Prerelease] IS NOT NULL THEN '-' + [Prerelease] ELSE '' END)) AS NVARCHAR(50))
	                       FROM dbo.ParseNuGetVersion(@Version_Text))

	IF EXISTS(
		SELECT *
		  FROM [NuGetPackages]
		  WITH (UPDLOCK)
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Package_Id] = @Package_Id 
		   AND [Version_Text] = @Version_Text
		)
	BEGIN

		UPDATE [NuGetPackages]
		   SET [Cached_Indicator] = 'N'
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Package_Id] = @Package_Id 
		   AND [Version_Text] = @Version_Text

		SET @Pulled_Indicator = 'Y'
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [NuGetPackages_PullCached] TO [ProGetUser_Role]